==> openjdk-17_17.0.17+10.orig.tar.xz: openjdk-17-17.0.17+10/test/hotspot/jtreg/runtime/Metaspace/MaxMetaspaceSizeTest.java <==
/*
 * Copyright (c) 2017, 2023, Oracle and/or its affiliates. All rights reserved.
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 *
 * This code is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License version 2 only, as
 * published by the Free Software Foundation.
 *
 * This code is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * version 2 for more details (a copy is included in the LICENSE file that
 * accompanied this code).
 *
 * You should have received a copy of the GNU General Public License version
 * 2 along with this work; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
 * or visit www.oracle.com if you need additional information or have any
 * questions.
 */

import jdk.test.lib.process.ProcessTools;
import jdk.test.lib.process.OutputAnalyzer;

/*
 * @test MaxMetaspaceSizeTest
 * @requires vm.bits == 64 & vm.opt.final.UseCompressedOops == true
 * @requires vm.flagless
 * @bug 8087291
 * @library /test/lib
 * @run driver MaxMetaspaceSizeTest
 */

public class MaxMetaspaceSizeTest {
    public static void main(String... args) throws Exception {
        ProcessBuilder pb = ProcessTools.createLimitedTestJavaProcessBuilder(
            "-Xmx1g",
            "-XX:MaxMetaspaceSize=4K",
            "-XX:+UseCompressedClassPointers",
            "-XX:CompressedClassSpaceSize=1g",
            "--version");
        OutputAnalyzer output = new OutputAnalyzer(pb.start());
        // We do not explicitly limit MaxMetaspaceSize to a lower minimum. User can get as low as he wants.
        // However, you most certainly will hit either one of
        // "OutOfMemoryError: Metaspace" or
        // "OutOfMemoryError: Compressed class space"
        output.shouldMatch("OutOfMemoryError.*(Compressed class space|Metaspace)");
        output.shouldNotHaveExitValue(0);
    }
}

==> openjdk-25_25+36.orig.tar.xz: openjdk-25-25+36/test/hotspot/jtreg/runtime/Metaspace/MaxMetaspaceSizeTest.java <==
/*
 * Copyright (c) 2017, 2024, Oracle and/or its affiliates. All rights reserved.
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 *
 * This code is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License version 2 only, as
 * published by the Free Software Foundation.
 *
 * This code is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * version 2 for more details (a copy is included in the LICENSE file that
 * accompanied this code).
 *
 * You should have received a copy of the GNU General Public License version
 * 2 along with this work; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
 * or visit www.oracle.com if you need additional information or have any
 * questions.
 */

import jdk.test.lib.process.ProcessTools;
import jdk.test.lib.process.OutputAnalyzer;

/*
 * @test MaxMetaspaceSizeTest
 * @requires vm.bits == 64 & vm.opt.final.UseCompressedOops == true
 * @requires vm.flagless
 * @bug 8087291
 * @library /test/lib
 * @run driver MaxMetaspaceSizeTest
 */

public class MaxMetaspaceSizeTest {
    public static void main(String... args) throws Exception {
        ProcessBuilder pb = ProcessTools.createLimitedTestJavaProcessBuilder(
            "-Xshare:off",
            "-Xmx1g",
            "-XX:MaxMetaspaceSize=4K",
            "-XX:+UseCompressedClassPointers",
            "-XX:CompressedClassSpaceSize=1g",
            "--version");
        OutputAnalyzer output = new OutputAnalyzer(pb.start());
        // -Xshare:off --version loads hundreds of classes and will hit either one of
        // "OutOfMemoryError: Metaspace" or
        // "OutOfMemoryError: Compressed class space"
        output.shouldMatch("OutOfMemoryError.*(Compressed class space|Metaspace)");
        output.shouldNotHaveExitValue(0);
    }
}
